/*
** Module   : BufferReference.java
** Abstract : interface which must be implemented by DMO dynamic proxy
**            instances
**
** Copyright (c) 2005-2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- --JPRM-- -----------------Description--------------------
** 001 ECF 20050916   @22893 Created initial version. Interface used by
**                           persistence framework to access RecordBuffer
**                           instance from a DMO dynamic proxy.
** 002 ECF 20061027   @30765 Extends DataModelObject marker interface.
**                           Avoids unnecessary casting in persistence
**                           API implementation.
** 003 ECF 20130122          Made public so that com.goldencode.proxy can
**                           access.
*/ 

package com.goldencode.p2j.persist;

/**
 * Interface which must be implemented by any DMO dynamic proxy object, to
 * provide the persistence framework access to the backing record buffer.
 * This is necessary because the {@link RecordBuffer} object is not exposed
 * to application code which manipulates DMO instances, yet the persistence
 * framework needs to be able to retrieve the backing buffer when it is
 * handed a DMO proxy instance by client code. This solution takes advantage
 * of the capability of a dynamic proxy to implement multiple interfaces,
 * and preempts the need for a separate mapping of DMO to record buffer.
 */
public interface BufferReference
extends DataModelObject
{
   /**
    * Get the <code>RecordBuffer</code> instance associated with this object.
    *
    * @return  Record buffer associated with this object.
    */
   public RecordBuffer buffer();
}
